Dear all,

attached is a patch to integer_traits.hpp, enabling it to be compiled under 
NetBSD.

Kind regards,
Angus
Index: boost/integer_traits.hpp
===================================================================
RCS file: /usr/local/lyx/cvsroot/lyx-devel/boost/boost/integer_traits.hpp,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -p -r1.11 -r1.12
--- boost/integer_traits.hpp	7 Aug 2003 12:09:23 -0000	1.11
+++ boost/integer_traits.hpp	23 Aug 2003 10:07:08 -0000	1.12
@@ -99,13 +99,14 @@ class integer_traits<wchar_t>
 #elif (defined(__sgi) && (!defined(__SGI_STL_PORT) || __SGI_STL_PORT < 0x400))\
     || (defined __APPLE__)\
     || (defined(__OpenBSD__) && defined(__GNUC__))\
+    || (defined(__NetBSD__) && defined(__GNUC__))\
     || (defined(__FreeBSD__) && defined(__GNUC__))\
     || (defined(__hpux) && defined(__GNUC__) && (__GNUC__ == 3) && !defined(__SGI_STL_PORT))
     // No WCHAR_MIN and WCHAR_MAX, wchar_t has the same range as int.
     //  - SGI MIPSpro with native library
     //  - gcc 3.x on HP-UX
     //  - Mac OS X with native library
     //  - gcc on FreeBSD
     public detail::integer_traits_base<wchar_t, INT_MIN, INT_MAX>
 #elif defined(__hpux) && defined(__GNUC__) && (__GNUC__ == 2) && !defined(__SGI_STL_PORT)
     // No WCHAR_MIN and WCHAR_MAX, wchar_t has the same range as unsigned int.
@@ -99,13 +99,14 @@ class integer_traits<wchar_t>
     //  - gcc 3.x on HP-UX
     //  - Mac OS X with native library
-    //  - gcc on FreeBSD
+    //  - gcc on FreeBSD, OpenBSD and NetBSD
     public detail::integer_traits_base<wchar_t, INT_MIN, INT_MAX>
 #elif defined(__hpux) && defined(__GNUC__) && (__GNUC__ == 2) && !defined(__SGI_STL_PORT)
_______________________________________________
Unsubscribe & other changes: http://lists.boost.org/mailman/listinfo.cgi/boost

Reply via email to